@@ -325,3 +325,18 @@ def format_line_count_break(padding: int) -> str:
     return format_text(
         " " * max(0, padding - len("...")) + "...\n", STYLE["detector_line_start"]
     )
+
+
+def format_quota_color(remaining: int, limit: int) -> str:
+    if limit == 0:
+        return format_text(str(remaining), {"fg": "white"})
+
+    available_percent = remaining / limit
+    if available_percent < 0.25:
+        color = "red"
+    elif available_percent < 0.75:
+        color = "yellow"
+    else:
+        color = "green"
+
+    return format_text(str(remaining), {"fg": color})
